/* Public domain. */

#include <fcntl.h>
#include "djbunix.h"

int uncoe (int fd)
{
   register int flags = fcntl(fd, F_GETFD, 0) ;
   if (flags == -1) return -1 ;
   return fcntl(fd, F_SETFD, flags & ~FD_CLOEXEC) ;
}
